CAPEC = {
   '1': 'Abuse of Functionality',
   '2': 'Spoofing',
   '3': 'Probabilistic Techniques',
   '4': 'Exploitation of Autentication',
   '5': 'Resource Depletion',
   '6': 'Exploitation of Privilege/Trust',
   '7': 'Injection',
   '8': 'Data Structure Attacks',
   '9': 'Data Leakage Attacks',
   '10': 'Resource Manipulation',
   '11': 'Time and State Attacks'
}

